@@ -3,7 +3,6 @@
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE LambdaCase #-}
 {-# LANGUAGE NamedFieldPuns #-}
-{-# LANGUAGE RecordWildCards #-}
 {-# LANGUAGE TypeFamilies #-}
 
 -- | Types used while planning how to build everything in a project.
@@ -58,6 +57,7 @@ module Distribution.Client.ProjectPlanning.Types
   , isTestComponentTarget
   , isBenchComponentTarget
   , componentOptionalStanza
+  , componentTargetName
 
     -- * Setup script
   , SetupScriptStyle (..)
@@ -275,6 +275,7 @@ data ElaboratedConfiguredPackage = ElaboratedConfiguredPackage
   , elabProgramPaths :: Map String FilePath
   , elabProgramArgs :: Map String [String]
   , elabProgramPathExtra :: [FilePath]
+  , elabConfiguredPrograms :: [ConfiguredProgram]
   , elabConfigureScriptArgs :: [String]
   , elabExtraLibDirs :: [FilePath]
   , elabExtraLibDirsStatic :: [FilePath]
@@ -862,6 +863,10 @@ data ComponentTarget = ComponentTarget ComponentName SubComponentTarget
 instance Binary ComponentTarget
 instance Structured ComponentTarget
 
+-- | Extract the component name from a 'ComponentTarget'.
+componentTargetName :: ComponentTarget -> ComponentName
+componentTargetName (ComponentTarget cname _) = cname
+
 -- | Unambiguously render a 'ComponentTarget', e.g., to pass
 -- to a Cabal Setup script.
 showComponentTarget :: PackageId -> ComponentTarget -> String
